@@ -24,7 +24,7 @@ import time
 import boto3
 
 from airflow.providers.amazon.aws.operators.ec2 import EC2CreateInstanceOperator, EC2TerminateInstanceOperator
-from airflow.providers.amazon.aws.operators.ssm import SsmRunCommandOperator
+from airflow.providers.amazon.aws.operators.ssm import SsmGetCommandInvocationOperator, SsmRunCommandOperator
 from airflow.providers.amazon.aws.sensors.ssm import SsmRunCommandCompletedSensor
 from airflow.sdk import DAG, chain, task
 
@@ -207,6 +207,14 @@ with DAG(
     )
     # [END howto_sensor_run_command]
 
+    # [START howto_operator_get_command_invocation]
+    get_command_output = SsmGetCommandInvocationOperator(
+        task_id="get_command_output",
+        command_id="{{ ti.xcom_pull(task_ids='run_command') }}",
+        instance_id=instance_id,
+    )
+    # [END howto_operator_get_command_invocation]
+
     delete_instance = EC2TerminateInstanceOperator(
         task_id="terminate_instance",
         trigger_rule=TriggerRule.ALL_DONE,
@@ -227,6 +235,7 @@ with DAG(
         # TEST BODY
         run_command,
         await_run_command,
+        get_command_output,
         # TEST TEARDOWN
         delete_instance,
         delete_instance_profile(instance_profile_name, role_name),
